@@ -138,7 +138,7 @@ class ROHSA(object):
                        n_gauss=3, lambda_amp=1000, lambda_mu=1000, lambda_sig=1000, lambda_var_amp=0, lambda_var_mu=0, lambda_var_sig=1000, lambda_lym_sig=0, 
                        amp_fact_init=0.66, sig_init = 4., lb_sig_init=1., ub_sig_init=100., lb_sig=0.001, ub_sig=100., init_option="mean", maxiter_init=15000, 
                        maxiter=800, m=10, noise=".false.", regul = ".true.", descent = ".true.", lstd = 1, ustd = 20, iprint = -1, iprint_init = -1, 
-                       save_grid=".true.", lym=".false.", init_spec=".false."):
+                       save_grid=".true.", lym=".false.", init_spec=".false.", norm_var=".false."):
 
         if not filename : 
             print("Need an input filename")
@@ -185,6 +185,7 @@ class ROHSA(object):
         input_file.write("    ,save_grid =  "+save_grid+'\n')
         input_file.write("    ,lym =  "+lym+'\n')
         input_file.write("    ,init_spec =  "+init_spec+'\n')
+        input_file.write("    ,norm_var =  "+norm_var+'\n')
         input_file.write("    /"+'\n')
         input_file.close()
 
